
TODO_62_75_33_41: do not hardcode `plugin_instance_id`

Instead of hardcoding, consider:
*   Per-plugin config for required type of plugin.
*   Server-wide-default config for required type of plugin.

